summaryrefslogtreecommitdiffstats
path: root/lfq.c
diff options
context:
space:
mode:
authorJérémy Zurcher <jeremy@asynk.ch>2009-11-03 22:20:45 +0100
committerJérémy Zurcher <jeremy@asynk.ch>2009-11-03 22:20:45 +0100
commit74a60162675fae9ac18fc98ebd3d8626e92719f3 (patch)
tree12e745df337664afc71e852af25aa4a5e2f75ea9 /lfq.c
parentee32b123e08a04998594146cb9258ca1fa4ec621 (diff)
downloadlock_free-74a60162675fae9ac18fc98ebd3d8626e92719f3.zip
lock_free-74a60162675fae9ac18fc98ebd3d8626e92719f3.tar.gz
lfq_push => lfq_push_tail, lfq_pop => lfq_pop_head
Diffstat (limited to 'lfq.c')
-rw-r--r--lfq.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/lfq.c b/lfq.c
index b2bd3e3..8fa9758 100644
--- a/lfq.c
+++ b/lfq.c
@@ -36,7 +36,7 @@ void lfq_init( lfq_t *q ) {
}
/* push a node at the tail of q */
-void lfq_push( lfq_t *q, pointer_t *node ) {
+void lfq_push_tail( lfq_t *q, pointer_t *node ) {
pointer_t tail;
pointer_t last;
pointer_t tmp;
@@ -79,8 +79,8 @@ void lfq_push( lfq_t *q, pointer_t *node ) {
cas( &q->tail.split, tail.split, tmp.split );
}
-/* shift a node from the head of q */
-pointer_t* shift( lfq_t *q ) {
+/* pop a node from the head of q */
+pointer_t* pop_head( lfq_t *q ) {
pointer_t head;
pointer_t tail;
pointer_t tmp;